@@ -35,7 +35,7 @@ var gMigrateWizard = {
                                                       1);
 
         migLOG("migrators: " + window.arguments.length);
-        for each (var migrator in window.arguments[0]) {
+        for (var migrator of window.arguments[0]) {
             var listItem = document.createElement("listitem");
             listItem.setAttribute("type", "checkbox");
             listItem.setAttribute("checked", true);
@@ -182,9 +182,9 @@ var gDataMigrator = {
                          this.checkWindowsMail,
                          this.checkIcal];
         // XXX also define a category and an interface here for pluggability
-        for each (var migrator in migrators) {
+        for (var migrator of migrators) {
             var migs = migrator.call(this);
-            for each (var dm in migs) {
+            for (var dm of migs) {
                 DMs.push(dm);
             }
         }
@@ -196,9 +196,9 @@ var gDataMigrator = {
         migLOG("DMs: " + DMs.length);
 
         var url = "chrome://calendar/content/calendar-migration-dialog.xul";
-//@line 207 "/var/tmp/portage/mail-client/thunderbird-45.8.0/work/thunderbird-45.8.0/calendar/base/content/dialogs/calendar-migration-dialog.js"
+//@line 207 "/var/tmp/portage/mail-client/thunderbird-52.1.0/work/thunderbird-52.1.0/calendar/base/content/dialogs/calendar-migration-dialog.js"
         openDialog(url, "migration", "modal,centerscreen,chrome,resizable=no,width=500,height=400", DMs);
-//@line 209 "/var/tmp/portage/mail-client/thunderbird-45.8.0/work/thunderbird-45.8.0/calendar/base/content/dialogs/calendar-migration-dialog.js"
+//@line 209 "/var/tmp/portage/mail-client/thunderbird-52.1.0/work/thunderbird-52.1.0/calendar/base/content/dialogs/calendar-migration-dialog.js"
     },
 
     /**
@@ -242,7 +242,7 @@ var gDataMigrator = {
             // For duplicate detection
             var calManager = getCalendarManager();
             var uris = [];
-            for each (var oldCal in calManager.getCalendars({})) {
+            for (var oldCal of calManager.getCalendars({})) {
                 uris.push(oldCal.uri);
             }
 
@@ -305,7 +305,7 @@ var gDataMigrator = {
         }
 
         // Now check all of the profiles in each of these folders for data
-        for each (var prof in profiles) {
+        for (var prof of profiles) {
             var dirEnum = prof.directoryEntries;
             while (dirEnum.hasMoreElements()) {
                 var profile = dirEnum.getNext().QueryInterface(Components.interfaces.nsIFile);
